======
spinda
======


.. image:: https://img.shields.io/pypi/v/spinda.svg
        :target: https://pypi.python.org/pypi/spinda

.. image:: https://img.shields.io/travis/kaixinbaba/spinda.svg
        :target: https://travis-ci.org/kaixinbaba/spinda

.. image:: https://readthedocs.org/projects/spinda/badge/?version=latest
        :target: https://spinda.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A tool for counting the number of lines of code and object relationships in a project...


* Free software: GNU General Public License v3
* Documentation: https://spinda.readthedocs.io.


Features
--------
- python project statistics v
- file count statistics v
- code line statistics v
- class object statistics v

TODO
--------
- class name same bug
- other language


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
